<?php
/****************************************************************************\|
| Gchats Visichat		                                               		  |
| Copyright (c) 2007-2012 Gchats http://www.gchats.com      		  |
| All rights reserved.                                                        |
+-----------------------------------------------------------------------------+
| PLEASE READ THE FULL TEXT OF SOFTWARE LICENSE AGREEMENT IN THE "COPYRIGHT"  |
| FILE PROVIDED WITH THIS DISTRIBUTION.                                       |
| THIS  AGREEMENT  EXPRESSES  THE  TERMS  AND CONDITIONS ON WHICH YOU MAY USE |
| GCHATS Visichat 2.0 PROGRAM WITH  THIS  AGREEMENT.                          |
| PLEASE   REVIEW   THE  TERMS  AND   CONDITIONS  OF  THIS  LICENSE AGREEMENT |
| CAREFULLY   BEFORE   INSTALLING   OR  USING  THE  SOFTWARE.  BY INSTALLING, |
| COPYING   OR   OTHERWISE   USING   THE   SOFTWARE,  YOU  AND  YOUR  COMPANY |
| (COLLECTIVELY,  "YOU")  ARE  ACCEPTING  AND AGREEING  TO  THE TERMS OF THIS |
| LICENSE   AGREEMENT.   IF  YOU    ARE  NOT  WILLING   TO  BE  BOUND BY THIS |
| AGREEMENT, DO  NOT INSTALL OR USE THE SOFTWARE.  VARIOUS   COPYRIGHTS   AND |
| OTHER   INTELLECTUAL   PROPERTY   RIGHTS    PROTECT   THE   SOFTWARE.  THIS |
| AGREEMENT IS A LICENSE AGREEMENT THAT GIVES  YOU  LIMITED  RIGHTS   TO  USE |
| THE  SOFTWARE   AND  NOT  AN  AGREEMENT  FOR SALE OR FOR  TRANSFER OF TITLE.|
| THE AUTHOR RETAINS ALL RIGHTS NOT EXPRESSLY GRANTED BY THIS AGREEMENT.      |
|                                                                             |
| The Initial Developer of the Original Code is Gchat Design Studio           |
\*****************************************************************************/
class language
{
	// default language
	var $language = "en";
	// XML Parser object
	var $parser;
	// tag property holds current xml tag
	var $tag = "";
	// data property holds all language tag values
	var $data;
	/*
	 * Class constructor, executes when class is being created
	 */
	function language()
	{
		// Load default language (english)
		$this->loadLanguage("en");	
	}
	
	/*
	 * Loading given language file in the language property
	 */
	function load()
	{		
		// if current language is not english then load it to avoid loading it twise
		if($this->language != "en")
		{
			// Loading first two characters only if a longer word has been set
			$this->loadLanguage(substr($this->language,0,2));
		}
	}
	/*
	 * Loading given language file and sending loaded data to the xml parser function
	 */
	function loadLanguage($ln)
	{
		// $file contains language file path & name
		$file = LIB_PATH.DS."..".DS."..".DS."languages".DS.$ln.".xml";
		
		// return if file not exists
		if(!is_file($file))
		{
			return;
		}
		
		// open language file
		$fp = fopen($file,"r");
		
		// initializing xml_data variable
		$xml_data = '';
		// loop upon reaching end of the file
		while (!feof($fp)) 
		{
			// reading content from file into the xml_data variable
			$xml_data .= fread($fp, 8192);
		}
		
		// close language file
		fclose($fp);
		
		// parsing data
		$this->parse($xml_data);
	}
	/*
	 *  Parsing given data
	 */
	function parse($data)
	{
		// Creating parser
		$this->parser =  xml_parser_create();
		// Set handler object
		xml_set_object($this->parser, $this);
		// setting start tag and end tag handler functions
		xml_set_element_handler($this->parser, "start_tag", "end_tag"); 
		// setting tag handler function
		xml_set_character_data_handler($this->parser, "contents"); 
		// parse the data
		xml_parse($this->parser, $data);
		// Free up the parser
		xml_parser_free($this->parser);
	}
	/*
	 * Invokes when parser gets start tag
	 */
	function start_tag($parser,$tag)
	{
		// Set current tag name
		$this->tag = $tag;
	}
	/*
	 * Invokes when parser reaches end of a tag
	 */
	function end_tag()
	{
		// set current tag name to blank when reaches end of a tag
		$this->tag = "";
	}
	/*
	 * Invokes when a tag content is available
	 */
	function contents($parser,$content)
	{
		// Saving the key as lowercase
		$this->data[strtolower($this->tag)] = $content;
	}
	/*
	 * Returns given tag name value from language file
	 */
	function get()
	{
		// Returns arguments passed to this function
		$args = func_get_args();
		// If no arguments, return blank
		if(count($args)==0)
		{
			return "";
		}
		// Set key to the first argument to lowercase
		$key = strtolower($args[0]);
		
		// if key is defined in the language xml file
		if(isset($this->data[$key]))
		{
			// store value in the label variable for adding arguments
			$label = $this->data[$key];
			
			// loop through given arguments
			for($i=1;$i<count($args);$i++)
			{
				// Replace arguments with %i variables
				$label = str_replace("%".$i,$args[$i],$label);
			}
			
			// returning the value
			return $label;
		}
		
		// otherwise return nothing
		return "";
	}
}
?>